import type { Db } from 'mongodb';
export type Message<T = unknown> = {
    id: string;
    ack: string;
    createdAt: Date;
    updatedAt: Date;
    payload: T;
    tries: number;
    occurrences?: number;
};
type AddOptions<T> = {
    hashKey?: keyof T | T;
    delay?: number;
};
export interface MongoDbQueue<T = unknown> {
    createIndexes(): Promise<void>;
    add(payload: T, options?: AddOptions<T>): Promise<string>;
    get(options?: {
        visibility?: number;
    }): Promise<Message<T> | undefined>;
    ping(ack: string, options?: {
        visibility?: number;
    }): Promise<string>;
    ack(ack: string): Promise<string>;
    total(): Promise<number>;
    size(): Promise<number>;
    inFlight(): Promise<number>;
    done(): Promise<number>;
}
export default function mongoDbQueue<T = unknown>(db: Db, name: string, options?: {
    visibility?: number;
}): MongoDbQueue<T>;
export {};
